@@ -12,13 +12,14 @@ use crate::{
         GraphicsMode,
         image::printer::{ImagePrinter, ImageRegistry},
     },
-    theme::{PresentationTheme, PresentationThemeSet},
+    theme::{raw::PresentationTheme, registry::PresentationThemeRegistry},
     third_party::{ThirdPartyConfigs, ThirdPartyRender},
 };
 use anyhow::anyhow;
 use clap::{CommandFactory, Parser, error::ErrorKind};
 use commands::speaker_notes::{SpeakerNotesEventListener, SpeakerNotesEventPublisher};
 use comrak::Arena;
+use config::ConfigLoadError;
 use directories::ProjectDirs;
 use std::{
     env::{self, current_dir},
@@ -27,6 +28,8 @@ use std::{
     rc::Rc,
     sync::Arc,
 };
+use terminal::emulator::TerminalEmulator;
+use theme::ThemeOptions;
 
 mod code;
 mod commands;
@@ -134,6 +137,7 @@ fn create_splash() -> String {
 struct Customizations {
     config: Config,
     themes: Themes,
+    themes_path: Option<PathBuf>,
     code_executor: SnippetExecutor,
 }
 
@@ -148,21 +152,25 @@ impl Customizations {
                 project_dirs.config_dir().into()
             }
         };
-        let themes = Self::load_themes(&configs_path)?;
+        let themes_path = configs_path.join("themes");
+        let themes = Self::load_themes(&themes_path)?;
+        let require_config_file = config_file_path.is_some();
         let config_file_path = config_file_path.unwrap_or_else(|| configs_path.join("config.yaml"));
-        let config = Config::load(&config_file_path)?;
+        let config = match Config::load(&config_file_path) {
+            Ok(config) => config,
+            Err(ConfigLoadError::NotFound) if !require_config_file => Default::default(),
+            Err(e) => return Err(e.into()),
+        };
         let code_executor = SnippetExecutor::new(config.snippet.exec.custom.clone(), cwd.to_path_buf())?;
-        Ok(Customizations { config, themes, code_executor })
+        Ok(Customizations { config, themes, themes_path: Some(themes_path), code_executor })
     }
 
-    fn load_themes(config_path: &Path) -> Result<Themes, Box<dyn std::error::Error>> {
-        let themes_path = config_path.join("themes");
-
+    fn load_themes(themes_path: &Path) -> Result<Themes, Box<dyn std::error::Error>> {
         let mut highlight_themes = HighlightThemeSet::default();
         highlight_themes.register_from_directory(themes_path.join("highlighting"))?;
 
-        let mut presentation_themes = PresentationThemeSet::default();
-        presentation_themes.register_from_directory(&themes_path)?;
+        let mut presentation_themes = PresentationThemeRegistry::default();
+        presentation_themes.register_from_directory(themes_path)?;
 
         let themes = Themes { presentation: presentation_themes, highlight: highlight_themes };
         Ok(themes)
@@ -190,7 +198,7 @@ impl CoreComponents {
         }
         let resources_path = resources_path.canonicalize().unwrap_or(resources_path);
 
-        let Customizations { config, themes, code_executor } =
+        let Customizations { config, themes, code_executor, themes_path } =
             Customizations::load(cli.config_file.clone().map(PathBuf::from), &resources_path)?;
 
         let default_theme = Self::load_default_theme(&config, &themes, cli);
@@ -212,7 +220,11 @@ impl CoreComponents {
         let graphics_mode = Self::select_graphics_mode(cli, &config);
         let printer = Arc::new(ImagePrinter::new(graphics_mode.clone())?);
         let registry = ImageRegistry(printer.clone());
-        let resources = Resources::new(resources_path.clone(), registry.clone());
+        let resources = Resources::new(
+            resources_path.clone(),
+            themes_path.unwrap_or_else(|| resources_path.clone()),
+            registry.clone(),
+        );
         let third_party_config = ThirdPartyConfigs {
             typst_ppi: config.typst.ppi.to_string(),
             mermaid_scale: config.mermaid.scale.to_string(),
@@ -258,6 +270,7 @@ impl CoreComponents {
             enable_snippet_execution_replace: config.snippet.exec_replace.enable,
             render_speaker_notes_only,
             auto_render_languages: config.options.auto_render_languages.clone(),
+            theme_options: ThemeOptions { font_size_supported: TerminalEmulator::capabilities().font_size },
         }
     }
 
@@ -349,13 +362,19 @@ fn run(cli: Cli) -> Result<(), Box<dyn std::error::Error>> {
         println!("{}", String::from_utf8_lossy(acknowledgements));
         return Ok(());
     } else if cli.list_themes {
+        // Load this ahead of time so we don't do it when we're already in raw mode.
+        TerminalEmulator::capabilities();
         let Customizations { config, themes, .. } =
             Customizations::load(cli.config_file.clone().map(PathBuf::from), &current_dir()?)?;
         let bindings = config.bindings.try_into()?;
-        let demo = ThemesDemo::new(themes, bindings, io::stdout())?;
+        let demo = ThemesDemo::new(themes, bindings)?;
         demo.run()?;
         return Ok(());
     }
+    // Disable this so we don't mess things up when generating PDFs
+    if cli.export_pdf || cli.generate_pdf_metadata || cli.enable_export_mode {
+        TerminalEmulator::disable_capability_detection();
+    }
 
     let Some(path) = cli.path.clone() else {
         Cli::command().error(ErrorKind::MissingRequiredArgument, "no path specified").exit();
@@ -399,6 +418,7 @@ fn run(cli: Cli) -> Result<(), Box<dyn std::error::Error>> {
             bindings: config.bindings,
             validate_overflows,
             max_columns: config.defaults.max_columns,
+            max_columns_alignment: config.defaults.max_columns_alignment,
         };
         let presenter = Presenter::new(
             &default_theme,
