@@ -4,7 +4,7 @@ use crate::{
         listener::{Command, CommandListener},
         speaker_notes::{SpeakerNotesEvent, SpeakerNotesEventPublisher},
     },
-    config::KeyBindingsConfig,
+    config::{KeyBindingsConfig, MaxColumnsAlignment},
     export::ImageReplacer,
     markdown::parse::{MarkdownParser, ParseError},
     presentation::{
@@ -17,15 +17,18 @@ use crate::{
         properties::WindowSize, validate::OverflowValidator,
     },
     resource::Resources,
-    terminal::image::printer::{ImagePrinter, ImageRegistry},
-    theme::PresentationTheme,
+    terminal::{
+        image::printer::{ImagePrinter, ImageRegistry},
+        printer::TerminalIo,
+    },
+    theme::{ProcessingThemeError, raw::PresentationTheme},
     third_party::ThirdPartyRender,
 };
 use std::{
     collections::HashSet,
     fmt::Display,
     fs,
-    io::{self, Stdout},
+    io::{self},
     mem,
     ops::Deref,
     path::Path,
@@ -40,6 +43,7 @@ pub struct PresenterOptions {
     pub bindings: KeyBindingsConfig,
     pub validate_overflows: bool,
     pub max_columns: u16,
+    pub max_columns_alignment: MaxColumnsAlignment,
 }
 
 /// A slideshow presenter.
@@ -102,8 +106,9 @@ impl<'a> Presenter<'a> {
         let drawer_options = TerminalDrawerOptions {
             font_size_fallback: self.options.font_size_fallback,
             max_columns: self.options.max_columns,
+            max_columns_alignment: self.options.max_columns_alignment,
         };
-        let mut drawer = TerminalDrawer::new(io::stdout(), self.image_printer.clone(), drawer_options)?;
+        let mut drawer = TerminalDrawer::new(self.image_printer.clone(), drawer_options)?;
         loop {
             if matches!(self.options.mode, PresentMode::Export) {
                 if let PresenterState::Failure { error, .. } = &self.state {
@@ -202,7 +207,7 @@ impl<'a> Presenter<'a> {
         Ok(false)
     }
 
-    fn render(&mut self, drawer: &mut TerminalDrawer<Stdout>) -> RenderResult {
+    fn render(&mut self, drawer: &mut TerminalDrawer) -> RenderResult {
         let result = match &self.state {
             PresenterState::Presenting(presentation) => {
                 drawer.render_operations(presentation.current_slide().iter_visible_operations())
@@ -354,14 +359,14 @@ impl<'a> Presenter<'a> {
         let export_mode = matches!(self.options.mode, PresentMode::Export);
         let mut presentation = PresentationBuilder::new(
             self.default_theme,
-            &mut self.resources,
+            self.resources.clone(),
             &mut self.third_party,
             self.code_executor.clone(),
             &self.themes,
             ImageRegistry(self.image_printer.clone()),
             self.options.bindings.clone(),
             self.options.builder_options.clone(),
-        )
+        )?
         .build(elements)?;
         if export_mode {
             ImageReplacer::default().replace_presentation_images(&mut presentation);
@@ -392,7 +397,7 @@ impl<'a> Presenter<'a> {
         }
     }
 
-    fn suspend(&self, drawer: &mut TerminalDrawer<Stdout>) {
+    fn suspend(&self, drawer: &mut TerminalDrawer) {
         #[cfg(unix)]
         unsafe {
             drawer.terminal.suspend();
@@ -494,6 +499,9 @@ pub enum LoadPresentationError {
 
     #[error(transparent)]
     Processing(#[from] BuildError),
+
+    #[error("processing theme: {0}")]
+    ProcessingTheme(#[from] ProcessingThemeError),
 }
 
 /// An error during the presentation.
