@@ -5,7 +5,6 @@ use crate::{
 use base64::{Engine, engine::general_purpose::STANDARD};
 use crossterm::{QueueableCommand, cursor::MoveToColumn, style::SetForegroundColor};
 use image::{AnimationDecoder, Delay, DynamicImage, EncodableLayout, ImageReader, RgbaImage, codecs::gif::GifDecoder};
-use rand::Rng;
 use std::{
     fmt,
     fs::{self, File},
@@ -145,7 +144,7 @@ impl KittyPrinter {
     }
 
     fn generate_image_id() -> u32 {
-        rand::thread_rng().gen_range(1..u32::MAX)
+        fastrand::u32(1..u32::MAX)
     }
 
     fn print_image<W>(
@@ -329,7 +328,7 @@ impl KittyPrinter {
         image_id: u32,
     ) -> Result<(), PrintImageError> {
         let color = Color::new((image_id >> 16) as u8, (image_id >> 8) as u8, image_id as u8);
-        writer.queue(SetForegroundColor(color.try_into()?))?;
+        writer.queue(SetForegroundColor(color.into()))?;
         if options.rows.max(options.columns) >= DIACRITICS.len() as u16 {
             return Err(PrintImageError::other("image is too large to fit in tmux"));
         }
@@ -399,7 +398,6 @@ impl PrintImage for KittyPrinter {
             GenericResource::Image(resource) => self.print_image(image.dimensions, resource, writer, options)?,
             GenericResource::Gif(frames) => self.print_gif(image.dimensions, frames, writer, options)?,
         };
-        writeln!(writer)?;
         Ok(())
     }
 }
