@@ -1,8 +1,8 @@
 pub(crate) mod ansi;
+pub(crate) mod capabilities;
 pub(crate) mod emulator;
 pub(crate) mod image;
 pub(crate) mod printer;
-pub(crate) mod query;
 
 pub(crate) use printer::{Terminal, TerminalWrite, should_hide_cursor};
 
